==> sale-3.2.4.jar: iot/sqls/common/getOpertionList.sql <==
SELECT
	*
FROM
	(
SELECT
    DISTINCT
	ui.f_userinfo_id,				                            --用户编号
	ui.f_userinfo_code,				                            --用户编号
	uf.f_user_id,						                            --表编号
	uf.f_userfiles_id,
	uf.f_meternumber,				                            --表号
	ui.f_user_name,					                            --用户名
	a.f_address,						                            --用户地址
	a.f_residential_area,                               --小区
	uf.f_user_type,                                     --用户类型
	uf.f_gasproperties,                                 --用气性质
	m1.f_insert_date,
	(case when m1.f_valveState = 1 then '关阀' when m1.f_valveState = 0 then '开阀' else '未上报' end) f_valvestate,	--阀门状态
	gb.id AS f_gasbrand_id,	                            --品牌识别列
	gb.f_meter_brand,				                            --气表品牌
	gm.id AS f_gasmodel_id,	                            --型号识别列
	gm.f_meter_style,				                    --气表型号
	gb.f_meter_type,				                            --气表类型
	case when uf.f_table_state='正常' then '在用' else uf.f_table_state end  f_table_state,		--气表状态
	gb.f_alias,                                         --表厂别名
  ui.f_orgid,
  uf.f_gas_date,
  uf.f_orgname,
  uf.f_depid,
  uf.f_operatorid,
  isnull(numbers,0) f_number,
  (case when uf.f_network_valve is null then '关闭'  else '开启' end) f_network_valve,	--阀控状态
  case when (
      {entity.findDialect()==$SqlServer$:
      $cast(replace(m1.f_signal,'%','') as decimal(18,2))$,
      $round(replace(m1.f_signal,'%','') ,2 )$}
          <=-101 or isnull(
     {entity.findDialect()==$SqlServer$:$CAST(m1.f_batterylevel AS NUMERIC)$,$to_number(m1.f_batterylevel)$}
      ,0)<4.00 or m1.f_magneticinterference=1 or m1.f_cycleshutvalue=1
    or m1.f_overcurrentprotection=1 or m1.f_leakageflag=1 or m1.f_splitalarm=1 or m1.f_xtipllstopflag=1) then '异常'
  else
   case when (select count(*) c from t_exception where f_meternumber = uf.f_meternumber
   and f_is_read = 0) = 0 then '正常' else '异常' end
   end f_userfiles_state
FROM
	t_userfiles uf
	LEFT JOIN t_user_address a on uf.f_useraddress_id=a.id
	LEFT JOIN t_userinfo ui ON (ui.f_userinfo_id= uf.f_userinfo_id)
	LEFT JOIN t_gasbrand gb ON (uf.f_gasbrand_id= gb.id)
	LEFT JOIN t_gasmodel gm ON (uf.f_gasmodel_id= gm.id)
	left join (select f_meternumber,max(id) maxid from t_meteread group by f_meternumber) m on uf.f_meternumber=m.f_meternumber
	left join t_meteread m1 on m.maxid=m1.id
	left join (select count(*) numbers,f_userfiles_id from t_gasparammanage where f_param_state='有效' group by f_userfiles_id) gpm on uf.f_userfiles_id=gpm.f_userfiles_id
	WHERE uf.f_table_state ='正常' and ui.f_user_state='正常' and gb.f_meter_type = '物联网表'
) t_userfiles
WHERE {condition}
ORDER BY
	f_userfiles_id DESC

==> sale-3.5.3.jar: iot/sqls/common/getOpertionList.sql <==
SELECT
	*
FROM
	(
SELECT
--    DISTINCT
--     ins.f_info,                                                 --开关阀备注
    (select top 1 f_info from t_instruct ins WHERE  f_instruct_type = '阀门控制' and uf.f_userfiles_id = ins.f_userfiles_id ORDER BY id desc) f_info,
	ui.f_userinfo_id,				                            --用户编号
	ui.f_userinfo_code,				                            --用户编号
	uf.f_user_id,						                            --表编号
	uf.f_userfiles_id,
	uf.f_meternumber,				                            --表号
	ui.f_user_name,					                            --用户名
	a.f_address,						                            --用户地址
	a.f_residential_area,                               --小区
	a.f_slice_area f_zones,                               --片区
	uf.f_user_type,                                     --用户类型
	uf.f_gasproperties,                                 --用气性质
	m1.f_insert_date,
	(case when m1.f_valveState = 1 then '关阀' when m1.f_valveState = 0 then '开阀' else '未上报' end) f_valvestate,	--阀门状态
	gb.id AS f_gasbrand_id,	                            --品牌识别列
	gb.f_meter_brand,				                            --气表品牌
	gm.id AS f_gasmodel_id,	                            --型号识别列
	gm.f_meter_style,				                    --气表型号
	gb.f_meter_type,				                            --气表类型
	case when uf.f_table_state='正常' then '在用' else uf.f_table_state end  f_table_state,		--气表状态
	gb.f_alias,                                         --表厂别名
  ui.f_orgid,
  uf.f_gas_date,
  uf.f_orgname,
  uf.f_depid,
  uf.f_operatorid,
  isnull(numbers,0) f_number,
  (case when uf.f_network_valve = '1' then '关闭'  else '开启' end) f_network_valve,	--阀控状态
  case when (
      {entity.findDialect()==$SqlServer$:
      $cast(replace(m1.f_signal,'%','') as decimal(18,2))$,
      $round(replace(m1.f_signal,'%','') ,2 )$}
          <=-101 or isnull(
     {entity.findDialect()==$SqlServer$:$CAST(m1.f_batterylevel AS NUMERIC)$,$to_number(m1.f_batterylevel)$}
      ,0)<4.00 or m1.f_magneticinterference=1 or m1.f_cycleshutvalue=1
    or m1.f_overcurrentprotection=1 or m1.f_leakageflag=1 or m1.f_splitalarm=1 or m1.f_xtipllstopflag=1) then '异常'
  else
   case when (select count(*) c from t_exception where f_meternumber = uf.f_meternumber
   and f_is_read = 0) = 0 then '正常' else '异常' end
   end f_userfiles_state
FROM
	t_userfiles uf
	LEFT JOIN t_user_address a on uf.f_useraddress_id=a.id
	LEFT JOIN t_userinfo ui ON (ui.f_userinfo_id= uf.f_userinfo_id)
	LEFT JOIN t_gasbrand gb ON (uf.f_gasbrand_id= gb.id)
	LEFT JOIN t_gasmodel gm ON (uf.f_gasmodel_id= gm.id)
    left join t_meteread m1 on uf.f_meteread_maxid = m1.id
	left join (select count(*) numbers,f_userfiles_id from t_gasparammanage where f_param_state='有效' group by f_userfiles_id) gpm on uf.f_userfiles_id=gpm.f_userfiles_id
--     left join t_instruct ins on uf.f_userfiles_id = ins.f_userfiles_id
    WHERE uf.f_table_state ='正常' and ui.f_user_state='正常' and gb.f_meter_type = '物联网表'
) t_userfiles
WHERE {condition}
ORDER BY
	f_userfiles_id DESC
